.. _ref-configuration:

=============
Configuration
=============

The following section lists each of the settings that can be configured
within Cartridge. Each setting is registered using the ``mezzanine.conf``
module which is discussed in
`Mezzanine's Configuration <http://mezzanine.jupo.org/docs/configuration.html>`_.

Default Settings
================

Cartridge defines the following settings:

.. include:: settings.rst
